Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1212)

Unified Diff: tests/compiler/dart2js/mirrors_test.dart

Issue 11340044: FieldMirror => VariableMirror (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/compiler/dart2js/mirrors_test.dart
diff --git a/tests/compiler/dart2js/mirrors_test.dart b/tests/compiler/dart2js/mirrors_test.dart
index b219f945b48dcb5577aed8156a57a3a0dbaf7fdf..49a1be069bf7a2f00dc1e3bf010761d23d158d54 100644
--- a/tests/compiler/dart2js/mirrors_test.dart
+++ b/tests/compiler/dart2js/mirrors_test.dart
@@ -67,9 +67,14 @@ main() {
// is not currently implemented in dart2js.
// TODO(johnniwinther): Add tests of Location and Source.
testPrivate(mirrors, helperLibrary, classes);
- // TODO(johnniwinther): Add tests of [LibraryMirror.functions],
- // [LibraryMirror.getters], [LibraryMirror.setters] and
- // [LibraryMirror.members].
+ // TODO(johnniwinther): Add thorough tests of [LibraryMirror.functions],
+ // [LibraryMirror.getters], [LibraryMirror.setters], [LibraryMirror.members],
+ // and [LibraryMirror.variable].
+ Expect.isNotNull(helperLibrary.functions);
+ Expect.isNotNull(helperLibrary.members);
+ Expect.isNotNull(helperLibrary.getters);
+ Expect.isNotNull(helperLibrary.setters);
+ Expect.isNotNull(helperLibrary.variables);
}
// Testing class Foo:
@@ -141,6 +146,15 @@ void testFoo(MirrorSystem system, LibraryMirror helperLibrary,
Expect.isNotNull(fooClassConstructors, "Constructors map is null");
Expect.isTrue(fooClassConstructors.isEmpty,
"Constructors map is unempty");
+
+ // TODO(johnniwinther): Add thorough tests of [ClassMirror.functions],
+ // [ClassMirror.getters], [ClassMirror.setters], [ClassMirror.members],
+ // and [ClassMirror.variable].
+ Expect.isNotNull(fooClass.functions);
+ Expect.isNotNull(fooClass.members);
+ Expect.isNotNull(fooClass.getters);
+ Expect.isNotNull(fooClass.setters);
+ Expect.isNotNull(fooClass.variables);
}
// Testing interface Bar:
@@ -696,7 +710,7 @@ void testPrivate(MirrorSystem system, LibraryMirror helperLibrary,
var privateField = privateClass.declaredMembers['_privateField'];
Expect.isNotNull(privateField);
- Expect.isTrue(privateField is FieldMirror);
+ Expect.isTrue(privateField is VariableMirror);
Expect.isTrue(privateField.isPrivate);
var privateGetter = privateClass.declaredMembers['_privateGetter'];

Powered by Google App Engine
This is Rietveld 408576698